pub enum ShrinkLevel {
Level0 = 0,
Level1 = 1,
Level2 = 2,
}Expand description
The amount of effort to put into reducing module size.
This is interpreted differently by different passes.
See the documentation of various OptimizationOptions
constructors for a general description of how these behave.
Variants